summaryrefslogtreecommitdiffstats
path: root/kubernetes/config/docker/init/src/config/dcaegen2/heat/entrypoint.sh
diff options
context:
space:
mode:
Diffstat (limited to 'kubernetes/config/docker/init/src/config/dcaegen2/heat/entrypoint.sh')
-rwxr-xr-xkubernetes/config/docker/init/src/config/dcaegen2/heat/entrypoint.sh16
1 files changed, 12 insertions, 4 deletions
diff --git a/kubernetes/config/docker/init/src/config/dcaegen2/heat/entrypoint.sh b/kubernetes/config/docker/init/src/config/dcaegen2/heat/entrypoint.sh
index 85c5ee2b13..bbf47a9bac 100755
--- a/kubernetes/config/docker/init/src/config/dcaegen2/heat/entrypoint.sh
+++ b/kubernetes/config/docker/init/src/config/dcaegen2/heat/entrypoint.sh
@@ -130,12 +130,12 @@ mv ./kubectl /usr/local/bin/kubectl
# Get the Kubernetes Node IP hosting the DCAE NGINX pod
NODE_IP=`kubectl get services dcaegen2 -o jsonpath='{.status.loadBalancer.ingress[0].ip}'`
-# # Source OpenStack parameters
-if [ "OPENSTACK_API_VERSION_HERE" = "v2.0" ]
+# Source OpenStack parameters to deploy DCAE
+if [ "DCAE_OS_API_VERSION_HERE" = "v2.0" ]
then
- source /opt/heat/OOM-openrc-v2.sh
+ source /opt/heat/DCAE-openrc-v2.sh
else
- source /opt/heat/OOM-openrc-v3.sh
+ source /opt/heat/DCAE-openrc-v3.sh
fi
# Create stasck if doens't exist
@@ -153,6 +153,14 @@ then
sed -i -e "s/DCAE_CONTROLLER_IP_HERE/$DCAE_CONTROLLER_IP/g" /opt/robot/vm_properties.py;
fi
+# Source OpenStack parameters for DNS Designate
+if [ "DNSAAS_API_VERSION_HERE" = "v2.0" ]
+then
+ source /opt/heat/DNS-openrc-v2.sh
+else
+ source /opt/heat/DNS-openrc-v3.sh
+fi
+
configure_dns_designate
monitor_nginx_node_ip \ No newline at end of file